#[repr(u8)]pub enum TintMode {
AlphaMask = 0,
Multiply = 1,
}Expand description
How tint color is applied to an image.
Variants
AlphaMask = 0
Alpha-mask tinting: tint_premul * source.alpha.
The source image’s alpha channel is used as a coverage mask, and the result is filled with the premultiplied tint color. This is the standard approach for glyph / monochrome image tinting.
Multiply = 1
Component-wise multiply: source * tint.
Each channel of the source pixel is multiplied by the corresponding channel of the tint color. This works well for full-color images.
Implementations